==> haskell-quickcheck-io-0.2.0-1032.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-quickcheck-io.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 quickcheck-io
version:              0.2.0
visibility:           public
id:                   quickcheck-io-0.2.0-CWlL4IxbPNeBBAU8PL3xjL
key:                  quickcheck-io-0.2.0-CWlL4IxbPNeBBAU8PL3xjL
license:              MIT
copyright:            (c) 2013-2017 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
homepage:             https://github.com/hspec/quickcheck-io#readme
synopsis:             Use HUnit assertions as QuickCheck properties
description:
    This package provides an orphan instance that allows you to
    use HUnit assertions as QuickCheck properties.

category:             Testing
abi:                  727bdac7854beb9219903826c8cff780
exposed:              True
exposed-modules:      Test.QuickCheck.IO
hidden-modules:       Paths_quickcheck_io
import-dirs:          /usr/lib/ghc-9.6.6/site-local/quickcheck-io-0.2.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/quickcheck-io-0.2.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/quickcheck-io-0.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quickcheck-io
hs-libraries:         HSquickcheck-io-0.2.0-CWlL4IxbPNeBBAU8PL3xjL
depends:
    HUnit-1.6.2.0-IE0oFrOTEOHIkscEaBk8om
    QuickCheck-2.15.0.1-DMgRmI5QzBCFdvvi5liF0L base-4.18.2.1

haddock-interfaces:
    /usr/share/doc/haskell-quickcheck-io/html/quickcheck-io.haddock

haddock-html:         /usr/share/doc/haskell-quickcheck-io/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-quickcheck-io-0.2.0-1034-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-quickcheck-io.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 quickcheck-io
version:              0.2.0
visibility:           public
id:                   quickcheck-io-0.2.0-DQKL7K7nLgG1d0kRb96ICb
key:                  quickcheck-io-0.2.0-DQKL7K7nLgG1d0kRb96ICb
license:              MIT
copyright:            (c) 2013-2017 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
homepage:             https://github.com/hspec/quickcheck-io#readme
synopsis:             Use HUnit assertions as QuickCheck properties
description:
    This package provides an orphan instance that allows you to
    use HUnit assertions as QuickCheck properties.

category:             Testing
abi:                  70649ff9a1fe6ac033b3dd3db3e4c883
exposed:              True
exposed-modules:      Test.QuickCheck.IO
hidden-modules:       Paths_quickcheck_io
import-dirs:          /usr/lib/ghc-9.6.6/site-local/quickcheck-io-0.2.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/quickcheck-io-0.2.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/quickcheck-io-0.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quickcheck-io
hs-libraries:         HSquickcheck-io-0.2.0-DQKL7K7nLgG1d0kRb96ICb
depends:
    HUnit-1.6.2.0-DydRkK1Ty562EFYgxreweA
    QuickCheck-2.15.0.1-1xFq7rzYyJMIIsLto0YgsS base-4.18.2.1

haddock-interfaces:
    /usr/share/doc/haskell-quickcheck-io/html/quickcheck-io.haddock

haddock-html:         /usr/share/doc/haskell-quickcheck-io/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
